@@ -12,7 +12,8 @@
 
 class KLineEdit;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class FreeBusyUrlWidget;
 
 class FreeBusyUrlDialog : public QDialog
@@ -33,7 +34,7 @@ class FreeBusyUrlWidget : public QWidget
     Q_OBJECT
 public:
     explicit FreeBusyUrlWidget(const AttendeeData::Ptr &, QWidget *parent = nullptr);
-    ~FreeBusyUrlWidget();
+    ~FreeBusyUrlWidget() override;
 
     void loadConfig();
     void saveConfig();
