@@ -9,8 +9,8 @@
 
 #include "editorconfig.h"
 
-#include "ui_dialogdesktop.h"
 #include "incidenceeditor_debug.h"
+#include "ui_dialogdesktop.h"
 
 #include <TagAttribute>
 #include <TagCreateJob>
@@ -24,13 +24,12 @@ IncidenceCategories::IncidenceCategories(Ui::EventOrTodoDesktop *ui)
 {
     setObjectName(QStringLiteral("IncidenceCategories"));
 
-    connect(mUi->mTagWidget, &Akonadi::TagWidget::selectionChanged, this,
-            &IncidenceCategories::onSelectionChanged);
+    connect(mUi->mTagWidget, &Akonadi::TagWidget::selectionChanged, this, &IncidenceCategories::onSelectionChanged);
 }
 
 void IncidenceCategories::onSelectionChanged(const Akonadi::Tag::List &list)
 {
-    Q_UNUSED(list);
+    Q_UNUSED(list)
     mDirty = true;
     checkDirtyStatus();
 }
@@ -43,7 +42,7 @@ void IncidenceCategories::load(const KCalendarCore::Incidence::Ptr &incidence)
     mMissingCategories.clear();
 
     if (mLoadedIncidence) {
-        auto *fetchJob = new Akonadi::TagFetchJob(this);
+        auto fetchJob = new Akonadi::TagFetchJob(this);
         fetchJob->fetchScope().fetchAttribute<Akonadi::TagAttribute>();
         connect(fetchJob, &Akonadi::TagFetchJob::result, this, &IncidenceCategories::onTagsFetched);
     }
@@ -81,9 +80,8 @@ void IncidenceCategories::createMissingCategories()
 {
     for (const QString &category : qAsConst(mMissingCategories)) {
         Akonadi::Tag missingTag = Akonadi::Tag::genericTag(category);
-        auto *createJob = new Akonadi::TagCreateJob(missingTag, this);
-        connect(createJob, &Akonadi::TagCreateJob::result, this,
-                &IncidenceCategories::onMissingTagCreated);
+        auto createJob = new Akonadi::TagCreateJob(missingTag, this);
+        connect(createJob, &Akonadi::TagCreateJob::result, this, &IncidenceCategories::onMissingTagCreated);
     }
 }
 
@@ -96,8 +94,7 @@ void IncidenceCategories::printDebugInfo() const
 {
     qCDebug(INCIDENCEEDITOR_LOG) << "selected categories = " << categories();
     qCDebug(INCIDENCEEDITOR_LOG) << "mMissingCategories = " << mMissingCategories;
-    qCDebug(INCIDENCEEDITOR_LOG) << "mLoadedIncidence->categories() = "
-                                 << mLoadedIncidence->categories();
+    qCDebug(INCIDENCEEDITOR_LOG) << "mLoadedIncidence->categories() = " << mLoadedIncidence->categories();
 }
 
 void IncidenceCategories::onTagsFetched(KJob *job)
@@ -106,7 +103,7 @@ void IncidenceCategories::onTagsFetched(KJob *job)
         qCWarning(INCIDENCEEDITOR_LOG) << "Failed to load tags " << job->errorString();
         return;
     }
-    auto *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
+    auto fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
     const Akonadi::Tag::List jobTags = fetchJob->tags();
 
     Q_ASSERT(mLoadedIncidence);
@@ -130,7 +127,7 @@ void IncidenceCategories::onMissingTagCreated(KJob *job)
         qCWarning(INCIDENCEEDITOR_LOG) << "Failed to create tag " << job->errorString();
         return;
     }
-    auto *createJob = static_cast<Akonadi::TagCreateJob *>(job);
+    auto createJob = static_cast<Akonadi::TagCreateJob *>(job);
     int count = mMissingCategories.removeAll(createJob->tag().name());
     Q_ASSERT(count > 0);
 
