@@ -10,23 +10,24 @@
 
 #include "incidenceeditor-ng.h"
 
-namespace Ui {
+namespace Ui
+{
 class EventOrTodoDesktop;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 /**
- * The IncidenceGeneralEditor keeps track of the following Incidence parts:
+ * The IncidenceWhatWhere editor keeps track of the following Incidence parts:
  * - Summary
  * - Location
- * - Categories
  */
 class IncidenceWhatWhere : public IncidenceEditor
 {
     Q_OBJECT
 public:
-    using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
     using IncidenceEditorNG::IncidenceEditor::load; // So we don't trigger -Woverloaded-virtual
+    using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
 
     explicit IncidenceWhatWhere(Ui::EventOrTodoDesktop *ui);
 
@@ -38,7 +39,7 @@ public:
     virtual void validate();
 
 private:
-    Ui::EventOrTodoDesktop *mUi = nullptr;
+    Ui::EventOrTodoDesktop *const mUi;
 };
 } // IncidenceEditorNG
 
