@@ -1,23 +1,7 @@
 /*
- * Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #ifndef RESOURCEMANAGEMENT_H
@@ -25,11 +9,11 @@
 
 #include "incidenceeditor_export.h"
 
-#include <Libkdepim/LdapClient>
-#include <Libkdepim/LdapClientSearch>
+#include <KLDAP/LdapClient>
+#include <KLDAP/LdapClientSearch>
 
-#include "CalendarSupport/FreeBusyCalendar"
 #include "resourceitem.h"
+#include <CalendarSupport/FreeBusyCalendar>
 
 #include <EventViews/ViewCalendar>
 
@@ -39,17 +23,22 @@ class Ui_resourceManagement;
 
 class QItemSelectionModel;
 
-namespace EventViews {
+namespace EventViews
+{
 class AgendaView;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
+/**
+ * @brief The ResourceManagement class
+ */
 class INCIDENCEEDITOR_EXPORT ResourceManagement : public QDialog
 {
     Q_OBJECT
 public:
     explicit ResourceManagement(QWidget *parent = nullptr);
-    ~ResourceManagement();
+    ~ResourceManagement() override;
 
     Q_REQUIRED_RESULT ResourceItem::Ptr selectedItem() const;
 
