@@ -10,14 +10,16 @@
 
 #include "ui_schedulingdialog.h"
 
-#include <QDialog>
 #include <QDateTime>
+#include <QDialog>
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class FreePeriodModel;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class ConflictResolver;
 class VisualFreeBusyWidget;
 
@@ -25,8 +27,8 @@ class SchedulingDialog : public QDialog, private Ui_Dialog
 {
     Q_OBJECT
 public:
-    SchedulingDialog(const QDate &startDate, const QTime &startTime, int duration, ConflictResolver *resolver, QWidget *parent);
-    ~SchedulingDialog();
+    explicit SchedulingDialog(const QDate &startDate, const QTime &startTime, int duration, ConflictResolver *resolver, QWidget *parent);
+    ~SchedulingDialog() override;
 
     Q_REQUIRED_RESULT QDate selectedStartDate() const;
     Q_REQUIRED_RESULT QTime selectedStartTime() const;
