@@ -13,12 +13,13 @@
 #include <KCalendarCore/IncidenceBase>
 
 #include <QDialog>
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class TemplateManagementDialog : public QDialog
 {
     Q_OBJECT
 public:
-    TemplateManagementDialog(QWidget *parent, const QStringList &templates, const QString &incidenceType);
+    explicit TemplateManagementDialog(QWidget *parent, const QStringList &templates, const QString &incidenceType);
 
 Q_SIGNALS:
     /* Emitted whenever the user hits apply, indicating that the currently
